import pytest
from dephell_licenses import licenses


@pytest.mark.parametrize('id, classifier', [
    ('MIT', 'OSI Approved :: MIT License'),
    ('mit', 'OSI Approved :: MIT License'),

    ('Apache 2.0', 'OSI Approved :: Apache Software License'),
    ('Apache-2.0', 'OSI Approved :: Apache Software License'),
    ('apache2', 'OSI Approved :: Apache Software License'),

    ('GPL 3.0', 'OSI Approved :: GNU General Public License v3 (GPLv3)'),
    ('GPLv3.0', 'OSI Approved :: GNU General Public License v3 (GPLv3)'),
    ('GPLv3', 'OSI Approved :: GNU General Public License v3 (GPLv3)'),
    ('GPL 3', 'OSI Approved :: GNU General Public License v3 (GPLv3)'),
    ('gpl3', 'OSI Approved :: GNU General Public License v3 (GPLv3)'),
])
def test_get_by_id(id: str, classifier: str):
    license = licenses.get_by_id(id)
    assert license.classifier == 'License :: ' + classifier


@pytest.mark.parametrize('classifier, id', [
    ('License :: OSI Approved :: MIT License', 'MIT'),
    ('License :: OSI Approved :: Apache Software License', 'Apache-2.0'),
    ('License :: OSI Approved :: GNU General Public License v3 (GPLv3)', 'GPL-3.0'),
])
def test_get_by_classifier(classifier: str, id: str):
    license = licenses.get_by_classifier(classifier)
    assert license.id == id


@pytest.mark.parametrize('name, id', [
    ('MIT License', 'MIT'),
    ('MIT', 'MIT'),
    ('mit', 'MIT'),

    ('Apache Software License', 'Apache-2.0'),
    ('Apache 2.0', 'Apache-2.0'),

    ('GPL 3.0', 'GPL-3.0'),
    ('GPL 3', 'GPL-3.0'),
    ('gpl3', 'GPL-3.0'),

    ('mpl2', 'MPL-2.0'),
    ('lgpl3', 'LGPL-3.0'),
])
def test_get_by_name(name: str, id: str):
    license = licenses.get_by_name(name)
    assert license.id == id



from dephell_licenses import licenses


def test_make_text():
    license = licenses.get_by_id('MIT')

    assert 'Copyright (c) <year> <copyright holders>' in license.make_text()
    assert 'beginOptional' not in license.make_text()
    assert license.make_text().strip().startswith('MIT License')

    assert 'MIT License 2018 Gram' in license.make_text(copyright='2018 Gram')



# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import os.path

readme = ''
here = os.path.abspath(os.path.dirname(__file__))
readme_path = os.path.join(here, 'README.rst')
if os.path.exists(readme_path):
    with open(readme_path, 'rb') as stream:
        readme = stream.read().decode('utf8')

setup(
    long_description=readme,
    name='dephell-licenses',
    version='0.1.7',
    description='Get info about OSS licenses',
    python_requires='>=3.5',
    project_urls={"repository": "https://github.com/dephell/dephell_licenses"},
    author='Gram',
    author_email='gram@orsinium.dev',
    license='MIT',
    keywords='dephell packaging licenses pypi',
    classifiers=[
        'Development Status :: 4 - Beta', 'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Operating System :: MacOS', 'Operating System :: Microsoft :: Windows',
        'Operating System :: Unix'
    ],
    packages=['dephell_licenses'],
    package_dir={"": "."},
    package_data={"dephell_licenses": ["*.json"]},
    install_requires=['attrs', 'requests'],
)
